@@ -52,21 +52,13 @@ im_fetch_set[] =
 	E_CONTACT_IM_GOOGLE_TALK
 };
 
+typedef struct dropdown_data dropdown_data;
 typedef enum {
 	E_CONTACT_MERGING_ADD,
 	E_CONTACT_MERGING_COMMIT,
 	E_CONTACT_MERGING_FIND
 } EContactMergingOpType;
 
-typedef struct _MergeDialogData {
-	GtkWidget *dialog;
-	GList *use_email_attr_list, *contact_email_attr_list, *match_email_attr_list;
-	GList *use_tel_attr_list, *contact_tel_attr_list, *match_tel_attr_list;
-	GList *use_im_attr_list, *contact_im_attr_list, *match_im_attr_list;
-	GList *use_sip_attr_list, *contact_sip_attr_list, *match_sip_attr_list;
-	gint row;
-} MergeDialogData;
-
 typedef struct {
 	EContactMergingOpType op;
 	ESourceRegistry *registry;
@@ -80,19 +72,16 @@ typedef struct {
 	EABMergingIdAsyncCallback id_cb;
 	EABMergingContactAsyncCallback c_cb;
 	gpointer closure;
-
-	MergeDialogData *merge_dialog_data;
 } EContactMergingLookup;
 
-typedef struct _dropdown_data {
+struct dropdown_data {
 	EContact *match;
 	EContactField field;
 
 	/* for E_CONTACT_EMAIL field */
 	GList *email_attr_list_item;
 	EVCardAttribute *email_attr;
-} dropdown_data;
-
+};
 static void match_query_callback (EContact *contact, EContact *match, EABContactMatchType type, gpointer closure);
 
 #define SIMULTANEOUS_MERGING_REQUESTS 20
@@ -101,33 +90,6 @@ static void match_query_callback (EContact *contact, EContact *match, EABContact
 static GList *merging_queue = NULL;
 static gint running_merge_requests = 0;
 
-static void
-merge_dialog_data_free (MergeDialogData *mdd)
-{
-	if (!mdd)
-		return;
-
-	gtk_widget_destroy (mdd->dialog);
-
-	g_list_free_full (mdd->match_email_attr_list, (GDestroyNotify) e_vcard_attribute_free);
-	g_list_free_full (mdd->contact_email_attr_list, (GDestroyNotify) e_vcard_attribute_free);
-	g_list_free (mdd->use_email_attr_list);
-
-	g_list_free_full (mdd->match_tel_attr_list, (GDestroyNotify) e_vcard_attribute_free);
-	g_list_free_full (mdd->contact_tel_attr_list, (GDestroyNotify) e_vcard_attribute_free);
-	g_list_free (mdd->use_tel_attr_list);
-
-	g_list_free_full (mdd->match_im_attr_list, (GDestroyNotify) e_vcard_attribute_free);
-	g_list_free_full (mdd->contact_im_attr_list, (GDestroyNotify) e_vcard_attribute_free);
-	g_list_free (mdd->use_im_attr_list);
-
-	g_list_free_full (mdd->match_sip_attr_list, (GDestroyNotify) e_vcard_attribute_free);
-	g_list_free_full (mdd->contact_sip_attr_list, (GDestroyNotify) e_vcard_attribute_free);
-	g_list_free (mdd->use_sip_attr_list);
-
-	g_free (mdd);
-}
-
 static void
 add_lookup (EContactMergingLookup *lookup)
 {
@@ -169,7 +131,6 @@ finished_lookup (void)
 static void
 free_lookup (EContactMergingLookup *lookup)
 {
-	merge_dialog_data_free (lookup->merge_dialog_data);
 	g_object_unref (lookup->registry);
 	g_object_unref (lookup->book_client);
 	g_object_unref (lookup->contact);
@@ -274,7 +235,6 @@ add_contact_ready_cb (GObject *source_object,
 
 	if (error != NULL)
 		g_error_free (error);
-	g_free (uid);
 }
 
 static void
@@ -283,11 +243,11 @@ doit (EContactMergingLookup *lookup,
 {
 	if (lookup->op == E_CONTACT_MERGING_ADD) {
 		if (force_modify)
-			e_book_client_modify_contact (lookup->book_client, lookup->contact, NULL, modify_contact_ready_cb, lookup);
+			e_book_client_modify_contact (lookup->book_client, lookup->contact, E_BOOK_OPERATION_FLAG_NONE, NULL, modify_contact_ready_cb, lookup);
 		else
-			e_book_client_add_contact (lookup->book_client, lookup->contact, NULL, add_contact_ready_cb, lookup);
+			e_book_client_add_contact (lookup->book_client, lookup->contact, E_BOOK_OPERATION_FLAG_NONE, NULL, add_contact_ready_cb, lookup);
 	} else if (lookup->op == E_CONTACT_MERGING_COMMIT)
-		e_book_client_modify_contact (lookup->book_client, lookup->contact, NULL, modify_contact_ready_cb, lookup);
+		e_book_client_modify_contact (lookup->book_client, lookup->contact, E_BOOK_OPERATION_FLAG_NONE, NULL, modify_contact_ready_cb, lookup);
 }
 
 static void
@@ -310,14 +270,14 @@ cancelit (EContactMergingLookup *lookup)
 static void
 dialog_map (GtkWidget *window,
             GdkEvent *event,
-            GtkWidget *grid)
+            GtkWidget *table)
 {
 	GtkAllocation allocation;
 	gint h, w;
 
-	gtk_widget_get_allocation (grid, &allocation);
+	gtk_widget_get_allocation (table, &allocation);
 
-	/* Spacing around the grid */
+	/* Spacing around the table */
 	w = allocation.width + 30;
 	/* buttons and outer spacing */
 	h = allocation.height + 60;
@@ -345,7 +305,7 @@ dropdown_changed (GtkWidget *dropdown,
 
 static void
 attr_dropdown_changed (GtkWidget *dropdown,
-			dropdown_data *data)
+                        dropdown_data *data)
 {
 	gchar *str = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (dropdown));
 
@@ -379,19 +339,19 @@ remove_contact_ready_cb (GObject *source_object,
 	}
 
 	e_book_client_add_contact (
-		book_client, lookup->contact, NULL,
+		book_client, lookup->contact, E_BOOK_OPERATION_FLAG_NONE, NULL,
 		add_contact_ready_cb, lookup);
 }
 
 static void
-create_dropdowns_for_multival_attr (GList *match_attr_list,
-				    GList *contact_attr_list,
-				    GList **use_attr_list,
-				    gint *row,
-				    GtkGrid *grid,
-				    const gchar * (*label_str) (EVCardAttribute*))
+create_dropdowns_for_multival_attr(GList *match_attr_list,
+                                   GList *contact_attr_list,
+                                   GList **use_attr_list,
+                                   gint *row,
+                                   GtkTable *table,
+                                   const gchar * (*label_str) (EVCardAttribute*) )
 {
-	GtkWidget *label, *dropdown;
+	GtkWidget *label, *hbox, *dropdown;
 	GList *miter, *citer;
 	GHashTable *match_attrs; /* attr in the 'match' contact from address book */
 
@@ -429,7 +389,9 @@ create_dropdowns_for_multival_attr (GList *match_attr_list,
 
 				(*row)++;
 				label = gtk_label_new (label_str (attr));
-				gtk_grid_attach (grid, label, 0, *row, 1, 1);
+				hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) label, FALSE, FALSE, 0);
+				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 0, 1, *row, *row + 1);
 
 				dropdown = gtk_combo_box_text_new ();
 				gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (dropdown), value);
@@ -439,7 +401,6 @@ create_dropdowns_for_multival_attr (GList *match_attr_list,
 				gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (dropdown), "");
 
 				gtk_combo_box_set_active (GTK_COMBO_BOX (dropdown), 0);
-
 				data->email_attr_list_item = g_list_last (*use_attr_list);
 				data->email_attr = attr;
 
@@ -448,7 +409,10 @@ create_dropdowns_for_multival_attr (GList *match_attr_list,
 					G_CALLBACK (attr_dropdown_changed), data);
 				g_object_set_data_full (G_OBJECT (dropdown), "eab-contact-merging::dropdown-data", data, g_free);
 
-				gtk_grid_attach (grid, dropdown, 1, *row, 1, 1);
+				hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) dropdown, FALSE, FALSE, 0);
+				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 1, 2, *row, *row + 1);
+				gtk_widget_show ((GtkWidget *) dropdown);
 			}
 		}
 		g_free (value);
@@ -471,46 +435,45 @@ set_attributes(EContact *contact, EContactField field, GList *use_attr_list)
 	g_list_free (citer);
 }
 
-static MergeDialogData *
-merge_dialog_data_create (EContactMergingLookup *lookup,
-			  GtkWidget *parent)
+static gint
+mergeit (EContactMergingLookup *lookup)
 {
-	GtkWidget *scrolled_window, *label, *dropdown;
+	GtkWidget *scrolled_window, *label, *hbox, *dropdown;
 	GtkWidget *content_area;
-	GtkGrid *grid;
+	GtkWidget *dialog;
+	GtkTable *table;
 	EContactField field;
 	gchar *string = NULL, *string1 = NULL;
-	MergeDialogData *mdd;
+	GList *use_email_attr_list, *contact_email_attr_list, *match_email_attr_list;
+	GList *use_tel_attr_list, *contact_tel_attr_list, *match_tel_attr_list;
+	GList *use_im_attr_list, *contact_im_attr_list, *match_im_attr_list;
+	GList *use_sip_attr_list, *contact_sip_attr_list, *match_sip_attr_list;
+	gint row = -1;
+	gint value = 0, result;
 
-	mdd = g_new0 (MergeDialogData, 1);
-	mdd->row = -1;
+	dialog = gtk_dialog_new ();
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Merge Contact"));
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
-	mdd->dialog = gtk_dialog_new ();
-	gtk_window_set_title (GTK_WINDOW (mdd->dialog), _("Merge Contact"));
-	gtk_container_set_border_width (GTK_CONTAINER (mdd->dialog), 5);
-	if (GTK_IS_WINDOW (parent))
-		gtk_window_set_transient_for (GTK_WINDOW (mdd->dialog), GTK_WINDOW (parent));
-
-	content_area = gtk_dialog_get_content_area (GTK_DIALOG (mdd->dialog));
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (
 		GTK_SCROLLED_WINDOW (scrolled_window),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	grid = GTK_GRID (gtk_grid_new ());
-	g_object_set (G_OBJECT (grid),
-		"border-width", 12,
-		"row-spacing", 6,
-		"column-spacing", 2,
-		NULL);
+	table = (GtkTable *) gtk_table_new (20, 2, FALSE);
+	gtk_container_set_border_width ((GtkContainer *) table, 12);
+	gtk_table_set_row_spacings (table, 6);
+	gtk_table_set_col_spacings (table, 2);
 
 	gtk_dialog_add_buttons (
-		GTK_DIALOG (mdd->dialog),
+		GTK_DIALOG (dialog),
 		_("_Cancel"), GTK_RESPONSE_CANCEL,
 		_("_Merge"), GTK_RESPONSE_OK,
 		NULL);
 
+
 	/*we match all the string fields of the already existing contact and the new contact.*/
 	for (field = E_CONTACT_FULL_NAME; field != (E_CONTACT_LAST_SIMPLE_STRING -1); field++) {
 		dropdown_data *data = NULL;
@@ -527,9 +490,11 @@ merge_dialog_data_create (EContactMergingLookup *lookup,
 			}
 
 			if (!(string1 && *string1) || (g_ascii_strcasecmp (string, string1))) {
-				mdd->row++;
+				row++;
 				label = gtk_label_new (e_contact_pretty_name (field));
-				gtk_grid_attach (grid, label, 0, mdd->row, 1, 1);
+				hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) label, FALSE, FALSE, 0);
+				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 0, 1, row, row + 1);
 				data = g_new0 (dropdown_data, 1);
 				dropdown = gtk_combo_box_text_new ();
 				gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (dropdown), string);
@@ -552,73 +517,61 @@ merge_dialog_data_create (EContactMergingLookup *lookup,
 				else
 					gtk_combo_box_set_active (GTK_COMBO_BOX (dropdown), 0);
 
-				gtk_grid_attach (grid, dropdown, 1, mdd->row, 1, 1);
+				hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+				gtk_box_pack_start (GTK_BOX (hbox), (GtkWidget *) dropdown, FALSE, FALSE, 0);
+				gtk_table_attach_defaults (table, (GtkWidget *) hbox, 1, 2, row, row + 1);
+				gtk_widget_show_all ((GtkWidget *) dropdown);
 			}
 		}
 	}
 
-	mdd->match_email_attr_list = e_contact_get_attributes (lookup->match, E_CONTACT_EMAIL);
-	mdd->contact_email_attr_list = e_contact_get_attributes (lookup->contact, E_CONTACT_EMAIL);
-	mdd->use_email_attr_list = NULL;
-	create_dropdowns_for_multival_attr (mdd->match_email_attr_list, mdd->contact_email_attr_list,
-	                                   &(mdd->use_email_attr_list), &(mdd->row), grid, eab_get_email_label_text);
+	match_email_attr_list = e_contact_get_attributes (lookup->match, E_CONTACT_EMAIL);
+	contact_email_attr_list = e_contact_get_attributes (lookup->contact, E_CONTACT_EMAIL);
+	use_email_attr_list = NULL;
+	create_dropdowns_for_multival_attr (match_email_attr_list, contact_email_attr_list,
+	                                   &use_email_attr_list, &row, table, eab_get_email_label_text);
 
-	mdd->match_tel_attr_list = e_contact_get_attributes (lookup->match, E_CONTACT_TEL);
-	mdd->contact_tel_attr_list = e_contact_get_attributes (lookup->contact, E_CONTACT_TEL);
-	mdd->use_tel_attr_list = NULL;
-	create_dropdowns_for_multival_attr (mdd->match_tel_attr_list, mdd->contact_tel_attr_list,
-	                                   &(mdd->use_tel_attr_list), &(mdd->row), grid, eab_get_phone_label_text);
+	match_tel_attr_list = e_contact_get_attributes (lookup->match, E_CONTACT_TEL);
+	contact_tel_attr_list = e_contact_get_attributes (lookup->contact, E_CONTACT_TEL);
+	use_tel_attr_list = NULL;
+	create_dropdowns_for_multival_attr (match_tel_attr_list, contact_tel_attr_list,
+	                                   &use_tel_attr_list, &row, table, eab_get_phone_label_text);
 
-	mdd->match_sip_attr_list = e_contact_get_attributes (lookup->match, E_CONTACT_SIP);
-	mdd->contact_sip_attr_list = e_contact_get_attributes (lookup->contact, E_CONTACT_SIP);
-	mdd->use_sip_attr_list = NULL;
-	create_dropdowns_for_multival_attr (mdd->match_sip_attr_list, mdd->contact_sip_attr_list,
-	                                   &(mdd->use_sip_attr_list), &(mdd->row), grid, eab_get_sip_label_text);
+	match_sip_attr_list = e_contact_get_attributes (lookup->match, E_CONTACT_SIP);
+	contact_sip_attr_list = e_contact_get_attributes (lookup->contact, E_CONTACT_SIP);
+	use_sip_attr_list = NULL;
+	create_dropdowns_for_multival_attr (match_sip_attr_list, contact_sip_attr_list,
+	                                   &use_sip_attr_list, &row, table, eab_get_sip_label_text);
 
-	mdd->match_im_attr_list = e_contact_get_attributes_set (lookup->match, im_fetch_set, G_N_ELEMENTS (im_fetch_set));
-	mdd->contact_im_attr_list = e_contact_get_attributes_set (lookup->contact, im_fetch_set, G_N_ELEMENTS (im_fetch_set));
-	mdd->use_im_attr_list = NULL;
-	create_dropdowns_for_multival_attr (mdd->match_im_attr_list, mdd->contact_im_attr_list,
-	                                   &(mdd->use_im_attr_list), &(mdd->row), grid, eab_get_im_label_text);
+	match_im_attr_list = e_contact_get_attributes_set (lookup->match, im_fetch_set, G_N_ELEMENTS (im_fetch_set));
+	contact_im_attr_list = e_contact_get_attributes_set (lookup->contact, im_fetch_set, G_N_ELEMENTS (im_fetch_set));
+	use_im_attr_list = NULL;
+	create_dropdowns_for_multival_attr (match_im_attr_list, contact_im_attr_list,
+	                                   &use_im_attr_list, &row, table, eab_get_im_label_text);
 
-	gtk_window_set_default_size (GTK_WINDOW (mdd->dialog), 420, 300);
-	gtk_container_add (GTK_CONTAINER (scrolled_window), GTK_WIDGET (grid));
+	gtk_window_set_default_size (GTK_WINDOW (dialog), 420, 300);
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled_window), GTK_WIDGET (table));
 	gtk_box_pack_start (GTK_BOX (content_area), GTK_WIDGET (scrolled_window), TRUE, TRUE, 0);
 	gtk_widget_show (scrolled_window);
 	g_signal_connect (
-		mdd->dialog, "map-event",
-		G_CALLBACK (dialog_map), grid);
-	gtk_widget_show_all (GTK_WIDGET (grid));
-
-	return mdd;
-}
-
-static gint
-mergeit (EContactMergingLookup *lookup,
-	 GtkWidget *parent)
-{
-	GList *ll;
-	gint value = 0, result, ii;
-
-	if (!lookup->merge_dialog_data)
-		lookup->merge_dialog_data = merge_dialog_data_create (lookup, parent);
-
-	if (lookup->merge_dialog_data->row == -1)
-		result = GTK_RESPONSE_OK;
-	else
-		result = gtk_dialog_run (GTK_DIALOG (lookup->merge_dialog_data->dialog));
+		dialog, "map-event",
+		G_CALLBACK (dialog_map), table);
+	gtk_widget_show_all ((GtkWidget *) table);
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	switch (result) {
+		gint ii;
+		GList *ll;
 	case GTK_RESPONSE_OK:
-		set_attributes (lookup->match, E_CONTACT_EMAIL, lookup->merge_dialog_data->use_email_attr_list);
-		set_attributes (lookup->match, E_CONTACT_TEL, lookup->merge_dialog_data->use_tel_attr_list);
-		set_attributes (lookup->match, E_CONTACT_SIP, lookup->merge_dialog_data->use_sip_attr_list);
+		set_attributes (lookup->match, E_CONTACT_EMAIL, use_email_attr_list);
+		set_attributes (lookup->match, E_CONTACT_TEL, use_tel_attr_list);
+		set_attributes (lookup->match, E_CONTACT_SIP, use_sip_attr_list);
 
 		for (ii = 0; ii < G_N_ELEMENTS (im_fetch_set); ii++) {
 			e_contact_set_attributes (lookup->match, im_fetch_set[ii], NULL);
 		}
 
-		for (ll = lookup->merge_dialog_data->use_im_attr_list; ll; ll = ll->next) {
+		for (ll = use_im_attr_list; ll; ll = ll->next) {
 			EVCard *vcard;
 			vcard = E_VCARD (lookup->match);
 			e_vcard_append_attribute (vcard, e_vcard_attribute_copy ((EVCardAttribute *) ll->data));
@@ -628,7 +581,7 @@ mergeit (EContactMergingLookup *lookup,
 		lookup->contact = g_object_ref (lookup->match);
 		e_book_client_remove_contact (
 			lookup->book_client,
-			lookup->match, NULL,
+			lookup->match, E_BOOK_OPERATION_FLAG_NONE, NULL,
 			remove_contact_ready_cb, lookup);
 		value = 1;
 		break;
@@ -637,7 +590,23 @@ mergeit (EContactMergingLookup *lookup,
 		value = 0;
 		break;
 	}
-	gtk_widget_hide (lookup->merge_dialog_data->dialog);
+	gtk_widget_destroy (dialog);
+
+	g_list_free_full (match_email_attr_list, (GDestroyNotify) e_vcard_attribute_free);
+	g_list_free_full (contact_email_attr_list, (GDestroyNotify) e_vcard_attribute_free);
+	g_list_free (use_email_attr_list);
+
+	g_list_free_full (match_tel_attr_list, (GDestroyNotify) e_vcard_attribute_free);
+	g_list_free_full (contact_tel_attr_list, (GDestroyNotify) e_vcard_attribute_free);
+	g_list_free (use_tel_attr_list);
+
+	g_list_free_full (match_im_attr_list, (GDestroyNotify) e_vcard_attribute_free);
+	g_list_free_full (contact_im_attr_list, (GDestroyNotify) e_vcard_attribute_free);
+	g_list_free (use_im_attr_list);
+
+	g_list_free_full (match_sip_attr_list, (GDestroyNotify) e_vcard_attribute_free);
+	g_list_free_full (contact_sip_attr_list, (GDestroyNotify) e_vcard_attribute_free);
+	g_list_free (use_sip_attr_list);
 
 	return value;
 }
@@ -665,6 +634,7 @@ check_if_same (EContact *contact,
 
 			if (num_of_email1 != num_of_email2) {
 				res = FALSE;
+				break;
 			} else { /* Do pairwise-comparisons on all of the e-mail addresses. */
 				iter1 = email_attr_list1;
 				while (iter1) {
@@ -912,7 +882,7 @@ response (GtkWidget *dialog,
 		cancelit (lookup);
 		break;
 	case GTK_RESPONSE_APPLY:
-		if (mergeit (lookup, dialog))
+		if (mergeit (lookup))
 			break;
 		return;
 	case GTK_RESPONSE_DELETE_EVENT:
@@ -991,7 +961,7 @@ eab_merging_book_add_contact (ESourceRegistry *registry,
 
 	g_return_val_if_fail (E_IS_SOURCE_REGISTRY (registry), FALSE);
 
-	lookup = g_new0 (EContactMergingLookup, 1);
+	lookup = g_new (EContactMergingLookup, 1);
 
 	lookup->op = E_CONTACT_MERGING_ADD;
 	lookup->registry = g_object_ref (registry);
@@ -1018,7 +988,7 @@ eab_merging_book_modify_contact (ESourceRegistry *registry,
 
 	g_return_val_if_fail (E_IS_SOURCE_REGISTRY (registry), FALSE);
 
-	lookup = g_new0 (EContactMergingLookup, 1);
+	lookup = g_new (EContactMergingLookup, 1);
 
 	lookup->op = E_CONTACT_MERGING_COMMIT;
 	lookup->registry = g_object_ref (registry);
@@ -1043,7 +1013,7 @@ eab_merging_book_find_contact (ESourceRegistry *registry,
 {
 	EContactMergingLookup *lookup;
 
-	lookup = g_new0 (EContactMergingLookup, 1);
+	lookup = g_new (EContactMergingLookup, 1);
 
 	lookup->op = E_CONTACT_MERGING_FIND;
 	lookup->registry = g_object_ref (registry);
