@@ -282,6 +282,19 @@ handle_term_signal (gpointer data)
 }
 #endif
 
+#ifdef G_OS_WIN32
+static gboolean
+is_any_gettext_catalog_installed (void)
+{
+	gchar txt[2] = { 0, 0 };
+	gchar *text;
+
+	text = gettext (txt);
+
+	return text && strcmp (text, "") != 0;
+}
+#endif
+
 G_GNUC_NORETURN static gboolean
 option_version_cb (const gchar *option_name,
                    const gchar *option_value,
@@ -311,7 +324,7 @@ static GOptionEntry entries[] = {
 	 * names, they MUST remain in English! */
 	  N_("Start Evolution showing the specified component. "
 	     "Available options are “mail”, “calendar”, “contacts”, "
-	     "“tasks”, and “memos”"), NULL },
+	     "“tasks”, and “memos”"), "COMPONENT" },
 	{ "geometry", 'g', 0, G_OPTION_ARG_STRING, &geometry,
 	  N_("Apply the given geometry to the main window"), "GEOMETRY" },
 	{ "offline", '\0', 0, G_OPTION_ARG_NONE, &start_offline,
@@ -486,13 +499,7 @@ main (gint argc,
 		exit (1);
 	}
 
-#ifdef HAVE_ICAL_UNKNOWN_TOKEN_HANDLING
-	ical_set_unknown_token_handling_setting (ICAL_DISCARD_TOKEN);
-#endif
-
-#ifdef HAVE_ICALTZUTIL_SET_EXACT_VTIMEZONES_SUPPORT
-	icaltzutil_set_exact_vtimezones_support (0);
-#endif
+	i_cal_set_unknown_token_handling_setting (I_CAL_DISCARD_TOKEN);
 
 #ifdef G_OS_WIN32
 	if (register_handlers || reinstall || show_icons) {
@@ -524,7 +531,7 @@ main (gint argc,
 		exit (0);
 	}
 
-	if (strcmp (gettext (""), "") == 0) {
+	if (!is_any_gettext_catalog_installed ()) {
 		/* No message catalog installed for the current locale
 		 * language, so don't bother with the localisations
 		 * provided by other things then either. Reset thread
